/*
 * Segment 10 System (Sys), SWE 10.1 StartStopp API
 * Copyright (C) 2007-2017 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:<br>
 * BitCtrl Systems GmbH<br>
 * Weißenfelser Straße 67<br>
 * 04229 Leipzig<br>
 * Phone: +49 341-490670<br>
 * mailto: info@bitctrl.de
 */
package de.bsvrz.sys.startstopp.api;

import java.util.Arrays;

import de.bsvrz.sys.funclib.commandLineArgs.ArgumentList;

/**
 * Zugriffsdaten für den Key-Store, der für die SSL-Kommunikation verwendet
 * wird.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class KeyStoreData {

    private static final String PARAM_KEY_MANAGER_PASSWORD = "-keyManagerPassword";
    private static final String PARAM_KEY_STORE_PASSWORD = "-keyStorePassword";
    private static final String PARAM_KEY_STORE_PATH = "-keyStorePath";

    private final String keyManagerPassword;
    private final String keyStorePassword;
    private final String keyStorePath;

    public KeyStoreData(String[] args) {

        ArgumentList argList = new ArgumentList(Arrays.copyOf(args, args.length));

        if (argList.hasArgument(PARAM_KEY_MANAGER_PASSWORD)) {
            keyManagerPassword = argList.fetchArgument(PARAM_KEY_MANAGER_PASSWORD).asString();
        } else {
            keyManagerPassword = "startstopp";
        }

        if (argList.hasArgument(PARAM_KEY_STORE_PASSWORD)) {
            keyStorePassword = argList.fetchArgument(PARAM_KEY_STORE_PASSWORD).asString();
        } else {
            keyStorePassword = "startstopp";
        }

        if (argList.hasArgument(PARAM_KEY_STORE_PATH)) {
            keyStorePath = argList.fetchArgument(PARAM_KEY_STORE_PATH).asString();
        } else {
            keyStorePath = StartStoppClient.class.getResource("keystore.p12").toExternalForm();
        }
    }

    public String getKeyManagerPassword() {
        return keyManagerPassword;
    }

    public String getKeyStorePassword() {
        return keyStorePassword;
    }

    public String getKeyStorePath() {
        return keyStorePath;
    }

}
